Module blaxel.api.workspaces
============================

Sub-modules
-----------
* blaxel.api.workspaces.accept_workspace_invitation
* blaxel.api.workspaces.create_worspace
* blaxel.api.workspaces.decline_workspace_invitation
* blaxel.api.workspaces.delete_workspace
* blaxel.api.workspaces.get_workspace
* blaxel.api.workspaces.invite_workspace_user
* blaxel.api.workspaces.leave_workspace
* blaxel.api.workspaces.list_workspace_users
* blaxel.api.workspaces.list_workspaces
* blaxel.api.workspaces.remove_workspace_user
* blaxel.api.workspaces.update_workspace
* blaxel.api.workspaces.update_workspace_user_role